NLSL: pmatrl.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
pmatrl.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | pmatrl (bss, ierr)

## Function/Subroutine Documentation

subroutine pmatrl | ( | integer, dimension(5,mxdim) | bss,
|  | integer | ierr
| ) |  |

Definition at line 79 of file pmatrl.f90.

Here is the call graph for this function:

Here is the caller graph for this function: